// disp.cpp -- Partial Zortech's disp module for Borland C++


#include <dos.h>
#include "disp.h"

#define VIDEO 0x010

int disp_numrows;
int disp_numcols;

// Character sets for disp_box function

char *scul = "";
char *scur = "۸";
char *scbl = "";
char *scbr = "۾";
char *schz = "";
char *scvt = "۳";


// Null routine not required by conio

void disp_close(void) {}


// Initialize display package

void disp_open(void)
{
  text_info info;

  gettextinfo(&info);
  disp_numrows = info.screenheight;
  disp_numcols = info.screenwidth;
}


// Position cursor at row, col where (0, 0) == upperleft corner

void disp_move(int row, int col)
{
  gotoxy(col + 1, row + 1);
}


// Erase from cursor to end of line

void disp_eeol(void)
{
  clreol();
}


// Erase from cursor to end of page

void disp_eeop(void)
{
  int xx, yy, y;
  text_info info;

  gettextinfo(&info);
  clreol();
  yy = wherey();
  xx = wherex();
  for (y = yy + 1; y <= info.screenheight; y++) {
    gotoxy(1, y);
    clreol();
  }
  gotoxy(xx, yy);
}


// Draw a box outline

void disp_box(int type, int attr, unsigned trow, unsigned lcol,
  unsigned brow, unsigned rcol)
{
  unsigned cul, cur, cbl, cbr, chz, cvt;   // Drawing chracters
  unsigned uattr = attr * 256;             // Attr in high byte

// Create drawing characters based on type and attribute

  if (type < 0 || type > 4) type = 0;
  cul = uattr + (unsigned char)scul[type];
  cur = uattr + (unsigned char)scur[type];
  cbl = uattr + (unsigned char)scbl[type];
  cbr = uattr + (unsigned char)scbr[type];
  chz = uattr + (unsigned char)schz[type];
  cvt = uattr + (unsigned char)scvt[type];

// Display four corners of box

  disp_pokew(trow, lcol, cul);
  disp_pokew(trow, rcol, cur);
  disp_pokew(brow, lcol, cbl);
  disp_pokew(brow, rcol, cbr);

// Display box outline

  for (int x = lcol + 1; x < rcol; x++) {
    disp_pokew(trow, x, chz);
    disp_pokew(brow, x, chz);
  }
  for (int y = trow + 1; y < brow; y++) {
    disp_pokew(y, lcol, cvt);
    disp_pokew(y, rcol, cvt);
  }

}


// Poke unsigned character and attribute into display

void disp_pokew(int row, int col, unsigned attrchar)
{
  col = col + 1;
  row = row + 1;
  puttext(col, row, col, row, &attrchar);
}


// Copy display buffer bytes to buffer at save pointer

void disp_peekbox(void far *save, unsigned trow, unsigned lcol,
  unsigned brow, unsigned rcol)
{
  gettext(lcol + 1, trow + 1, rcol + 1, brow + 1, save);
}


// Paint a box onscreen with an attribute and character

void disp_fillbox(unsigned attrchar, unsigned trow, unsigned lcol,
  unsigned brow, unsigned rcol)
{
  while (trow <= brow) {
    for (int i = lcol; i <= rcol; i++)
      disp_pokew(trow, i, attrchar);
    trow++;
  }
}


// Copy data saved by disp_peekbox back to display

void disp_pokebox(void far *save, unsigned trow, unsigned lcol,
  unsigned brow, unsigned rcol)
{
  puttext(lcol + 1, trow + 1, rcol + 1, brow + 1, save);
}


// Remove cursor from display

void disp_hidecursor(void)
{
  _setcursortype(_NOCURSOR);
}


// Redisplay hidden cursor

void disp_showcursor(void)
{
  _setcursortype(_NORMALCURSOR);
}


// Scroll the defined area up or down

void disp_scroll(int lines, unsigned ulrow, unsigned ulcol,
  unsigned lrrow, unsigned lrcol, unsigned attr)
{
  union REGS regs;

  if (lines < 0){
    regs.h.ah = 7;      // Scroll down
    lines = -lines;
  }
  else
    regs.h.ah = 6;      // Scroll up
  regs.h.ch = ulrow;
  regs.h.cl = ulcol;
  regs.h.dh = lrrow;
  regs.h.dl = lrcol;
  regs.h.bh = attr;
  if (ulrow >= lrrow)
    regs.h.al = 0;      // Clear window if top >= bottom row
  else
    regs.h.al = lines;  // Else scroll the specified number of lines
  int86(VIDEO, &regs, &regs);
}


// Display character c at cursor location

int disp_putc(int c)
{
  return putch(c);
}


// Return current display mode

int disp_getmode(void)
{
  text_info info;

  gettextinfo(&info);
  return info.currmode;
}


// Copyright (c) 1991 by Tom Swan. All rights reserved
// Revision 1.00    Date: 07/02/1991   Time: 08:04 pm

